Coverage for /home/tribaal/workspace/django-shop/shop/addressmodel/admin: 100.00%

# Coverage for /home/tribaal/workspace/django-shop/shop/addressmodel/admin : 100.00%

## 10 statements 10 run 0 missing 0 excluded 0 partial

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 | #-*- coding: utf-8 -*- from django.contrib import admin from django.contrib.admin.options import ModelAdmin from shop.addressmodel.models import Country, Address #class ClientAdmin(ModelAdmin): # pass #admin.site.register(Client, ClientAdmin) class CountryAdmin(ModelAdmin): pass class AddressAdmin(ModelAdmin): list_display = ( 'name', 'address', 'address2', 'zip_code', 'city', 'country', 'user_shipping', 'user_billing') raw_id_fields = ('user_shipping', 'user_billing') admin.site.register(Address, AddressAdmin) admin.site.register(Country, CountryAdmin)